# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-09-28 06:43
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_course', '0059_sectionattach_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserQuestionAnswerRecord',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('answer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.SectionQuestionOption')),
                ('question', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_course.SectionQuestion')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'ordering': ['-created_at'],
                'db_table': 'bee_django_course_user_question_answer_record',
            },
        ),
    ]



# -*- coding: utf-8 -*-
__author__ = 'bee'

import urllib, urllib2, pytz, json
from django.http import HttpResponse
from django.db.models import Count, Sum, Max, Min
from django.db.models.functions import TruncMonth, TruncDay
from django.utils import timezone

import datetime
from django.conf import settings
from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
from .models import UserLive

LOCAL_TIMEZONE = pytz.timezone('Asia/Shanghai')


# =====http====
def http_get(url):
    f = urllib.urlopen(url)
    s = f.read()
    return s


def http_post(url, parameters=None):
    parameters = urllib.urlencode(parameters)
    request = urllib2.Request(url, parameters)
    request.add_header('Content-Type', 'application/x-www-form-urlencoded')
    res_data = urllib2.urlopen(request, timeout=10)
    res = res_data.read()
    return res


# ====dt====
# 获取本地当前时间
def get_now(tz=LOCAL_TIMEZONE):
    return timezone.now()


class JSONResponse(HttpResponse):
    def __init__(self, obj):
        if isinstance(obj, dict):
            _json_str = json.dumps(obj)
        else:
            _json_str = obj
        super(JSONResponse, self).__init__(_json_str, content_type="application/json;charset=utf-8")


def page_it(request, query_set, url_param_name='page', items_per_page=25):
    paginator = Paginator(query_set, items_per_page)

    page = request.GET.get(url_param_name)
    try:
        rs = paginator.page(page)
    except PageNotAnInteger:
        rs = paginator.page(1)
    except EmptyPage:
        rs = paginator.page(paginator.num_pages)

    return rs


# 获取用户姓名
def get_user_name(user):
    try:
        user_name = getattr(user, settings.USER_NAME_FIELD)
    except:
        user_name = user.username
    return user_name


# 返回直播分钟数，直播次数，直播天数
def get_user_live_data(user, start_dt=None, end_dt=None):
    vod_list = UserLive.objects.filter(status__in=[1, 2]).filter(user=user).filter(record_status=10)
    if start_dt:
        vod_list = vod_list.filter(start_time__gte=start_dt)
    if end_dt:
        vod_list = vod_list.filter(start_time__lt=end_dt)
    if vod_list.count() == 0:
        return 0, 0, 0
    res_mins = vod_list.aggregate(
        sum_duration=Sum('duration'))
    days_qurey_set = vod_list.annotate(day=TruncDay('start_time', tzinfo=LOCAL_TIMEZONE)).values('day') \
        .annotate(count=Count('id'), total=Sum('duration')).values('day', 'count', 'total') \
        .order_by('day')
    days_count = days_qurey_set.count()
    return res_mins["sum_duration"] / 60, vod_list.count(), days_count


# 某人是否可以观看视频。
# 条件1：有权限，条件2：录制本人，条件3：超过48小时。
def can_view_expired_live(user,user_live):
    # 本人可看
    if user==user_live.user:
        return True
    if user.has_perm('bee_django_course.view_expired_userlives'):
        return True
    if hasattr(settings,"COURSE_LIVE_EXPIRED_HOURS"):
        expired_dt =user_live.start_time+datetime.timedelta(hours=settings.COURSE_LIVE_EXPIRED_HOURS)
        if timezone.now()<expired_dt:
            return True
    else:
        return True
    return False


#!/usr/bin/env python
# -*- coding:utf-8 -*-
__author__ = 'bee'
import json
from django.utils import timezone
from django.conf import settings
from utils import http_post


# 获取直播间id
def create_room(room_name):
    if not hasattr(settings, "GENSEE_CONFIG"):
        return
    create_webcast_parameters = {
        "subject": room_name.encode('utf-8'),
        "startTime": timezone.now(),
        "organizerToken": settings.GENSEE_CONFIG.student_organizerToken,
        "panelistToken": settings.GENSEE_CONFIG.student_panelistToken,
        "attendeeToken": "",
        "loginName": settings.GENSEE_CONFIG.gensee_manke_account.username,
        "password": settings.GENSEE_CONFIG.gensee_manke_account.password
    }
    create_webcast_res = gensee_api_post("/webcast/created", create_webcast_parameters)
    if create_webcast_res and create_webcast_res["code"] == "0":
        return create_webcast_res["id"]
    else:
        return None

# 删除直播间
def delete_room(room_id):
    if not hasattr(settings, "GENSEE_CONFIG"):
        return
    delete_webcast_parameters = {
        "webcastId": room_id,
        "loginName": settings.GENSEE_CONFIG.gensee_manke_account.username,
        "password": settings.GENSEE_CONFIG.gensee_manke_account.password
    }
    create_webcast_res = gensee_api_post("/webcast/deleted", delete_webcast_parameters)
    if create_webcast_res and create_webcast_res["code"] == "0":
        return True
    else:
        return False


# 获取直播间信息
def get_room_info(room_id):
    if not hasattr(settings, "GENSEE_CONFIG"):
        return
    live_webcast_res = gensee_api_post("/webcast/setting/info",
                                       {"webcastId": room_id, "loginName":
                                           settings.GENSEE_CONFIG.gensee_manke_account.username,
                                        "password": settings.GENSEE_CONFIG.gensee_manke_account.password})
    if live_webcast_res["code"] == "0":
        room = live_webcast_res
    else:
        room = None
    return room


def gensee_api_post(url, parameters):
    if not hasattr(settings, "GENSEE_CONFIG"):
        return
    url = settings.GENSEE_CONFIG.genseeUrl + url
    res = http_post(url, parameters)
    try:
        j = json.loads(res)
    except Exception as e:
        print(e)
        j = None
    return j
